@@ -1,6 +1,4 @@
 
-import data
-import os
 import cv2
 import numpy as np
 import torch
